searchData={"items":[{"type":"module","title":"Interval","doc":"Interval - A library for working with intervals in Elixir.\n\nIt is modelled after Postgres' range types. In cases where behaviour is ambiguous,\nthe \"correct\" behaviour is whatever Postgres does.\n\nAn interval represents the points between two endpoints.\n\nThe interval can be empty.\nThe empty interval is never contained in any other interval,\nand itself contains no points.\n\nIt can be left and/or right unbounded, in which case\nit contains all points in the unbounded direction.\nA fully unbounded interval contains all other intervals, except\nthe empty interval.","ref":"Interval.html"},{"type":"module","title":"Features - Interval","doc":"Supports intervals of stdlib types like `DateTime`.\nAlso comes with support for `Decimal` out of the box.\n\nAutomatically generates an `Ecto.Type` for use with Postgres' range types\n(see https://www.postgresql.org/docs/current/rangetypes.html)\n\nYou can very easily implement your own types into the interval\nwith the `Interval.__using__/1` macro.\n\nBuilt in intervals:\n  - `Interval.IntegerInterval`\n  - `Interval.FloatInterval`\n  - `Interval.DateInterval`\n  - `Interval.DateTimeInterval`\n  - `Interval.NaiveDateTimeInterval`\n  - `Interval.DecimalInterval`","ref":"Interval.html#module-features"},{"type":"module","title":"Interval Notation - Interval","doc":"Throughout the documentation and comments, you'll see a notation for\nwriting about intervals.\nAs this library is inspired by the functionality in PostgreSQL's range types,\nwe align ourselves with it's  notation choice and borrow it\n(https://www.postgresql.org/docs/current/rangetypes.html)\n\nThis notation is also described in ISO 31-11.\n\n    [left-inclusive, right-inclusive]\n    (left-exclusive, right-exclusive)\n    [left-inclusive, right-exclusive)\n    (left-exclusive, right-inclusive]\n    empty\n\nAn unbounded interval is written by omitting the bound type and point:\n\n    ,right-exclusive)\n    [left-inclusive,\n\nWhen specifying bound types we sometimes leave the point out and just write\nthe left and right bounds:\n\n    []\n    ()\n    (]\n    [)\n    (\n    )\n    [\n    ]","ref":"Interval.html#module-interval-notation"},{"type":"module","title":"Types of Interval - Interval","doc":"This library ships with a few different types of intervals.\nThe built-in intervals are:\n\n- `Interval.DateInterval` containing points of type `Date`\n- `Interval.DateTimeInterval` containing points of type `DateTime`\n- `Interval.NaiveDateTimeInterval` containing points of type `NaiveDateTime`\n- `Interval.FloatIntervalInterval` containing points of type `Float`\n- `Interval.IntegerIntervalInterval` containing points of type `Integer`\n- `Interval.DecimalInterval` containing points of type `Decimal` (See https://hexdocs.pm/decimal/2.0.0)\n\nHowever, you can quite easily implement an interval by implementing\nthe `Interval.Behaviour`.\n\nThe easiest way to do so, is by using the `Interval.__using__` macro:\n\n    defmodule MyInterval do\n      use Interval, type: MyType, discrete: false\n    end\n\nYou must implement a few functions defined in `Interval.Behaviour`.\nOnce that's done, all operations available in the `Interval` module (like\ninteresection, union, overlap etc) will work on your interval struct.\n\nAn obvious usecase for this would be to implement an interval that works\nwith the https://hexdocs.pm/decimal library.","ref":"Interval.html#module-types-of-interval"},{"type":"module","title":"Discrete vs Continuous intervals - Interval","doc":"Depending on the behaviour you want from your interval, it is either said to be\ndiscrete or continuous.\n\nA discrete interval represents a set of finite points (like integers).\nA continuous interval can be said to represent the infinite number of points between\ntwo endpoints (like an interval between two floats).\n\nWith discrete points, it is possible to define what the next and previous\npoint is, and we normalise these intervals to the bound type `[)`.\n\nThe distinction between a discrete and continuous interval is important\nbecause the two behave slightly different in some of the library functions.\n\nA discrete interval is adjacent to another discrete interval, if there\nis no points between the two interval.\nContrast this to continuous intervals of real numbers where there is always\nan infinite number of real numbers between two distinct real numbers,\nand so continuous intervals are only said to be adjacent to each other\nif they include the same point, and one point is inclusive where the other\nis exclusive.\n\nWhere relevant, the function documentation will mention the differences\nbetween discrete and continuous intervals.","ref":"Interval.html#module-discrete-vs-continuous-intervals"},{"type":"module","title":"Create an Interval - Interval","doc":"See `new/1`","ref":"Interval.html#module-create-an-interval"},{"type":"module","title":"Normalization - Interval","doc":"When creating an interval through `new/1`, it will get normalized\nso that intervals that represents the same points,\nare also represented in the same way in the struct.\nThis allows you to compare two intervals for equality by using `==`\n(and using pattern matching).\n\nIt is therefore not recommended to modify an interval struct directly,\nbut instead do so by using one of the functions that modify the interval.\n\nAn interval is said to be empty if it spans zero points.\nThe normalized form of an empty interval is the special interval struct\nwhere left and right is set to `:empty`,\nhowever a non-normalized empty struct will still correctly report\nempty via the `empty?/1` function.","ref":"Interval.html#module-normalization"},{"type":"macro","title":"Interval.__using__/1","doc":"Define an interval struct of a specific point type.\n\nSupport for `Ecto.Type` and the `Postgrex.Range` can be automatically\ngenerated by specifying `ecto_type:  ` when `use`ing.","ref":"Interval.html#__using__/1"},{"type":"macro","title":"Options - Interval.__using__/1","doc":"- `type` - The internal point type in this interval. *required*\n- `discrete` - Is this interval discrete? `default: false`","ref":"Interval.html#__using__/1-options"},{"type":"macro","title":"Examples - Interval.__using__/1","doc":"defmodule MyInterval do\n      use Interval, type: MyType, discrete: false\n    end","ref":"Interval.html#__using__/1-examples"},{"type":"function","title":"Interval.adjacent?/2","doc":"Check if two intervals are adjacent.\n\nTwo intervals are adjacent if they do not overlap, and there are no points between them.\n\nThis function is a shorthand for `adjacent_left_of(a, b) or adjacent_right_of?(a, b)`.","ref":"Interval.html#adjacent?/2"},{"type":"function","title":"Interval.adjacent_left_of?/2","doc":"Is the interval `a` adjacent to `b`, to the left of `b`.\n\n`a` is adjacent to `b` left of `b`, if `a` and `b` do _not_ overlap,\nand there are no points between `a.right` and `b.left`.\n\n    # a: [---)\n    # b:     [---)\n    # r: true\n\n    # a: [---]\n    # b:     [---]\n    # r: false (overlaps)\n\n    # a: (---)\n    # b:        (---)\n    # r: false (points exist between a.right and b.left)","ref":"Interval.html#adjacent_left_of?/2"},{"type":"function","title":"Examples - Interval.adjacent_left_of?/2","doc":"iex> adjacent_left_of?(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 2, right: 3))\n    true\n\n    iex> adjacent_left_of?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    false\n\n    iex> adjacent_left_of?(new(module: Interval.IntegerInterval, left: 3, right: 4), new(module: Interval.IntegerInterval, left: 1, right: 2))\n    false\n\n    iex> adjacent_left_of?(new(module: Interval.IntegerInterval, right: 2, bounds: \"[]\"), new(module: Interval.IntegerInterval, left: 3))\n    true","ref":"Interval.html#adjacent_left_of?/2-examples"},{"type":"function","title":"Interval.adjacent_right_of?/2","doc":"Is the interval `a` adjacent to `b`, to the right of `b`.\n\n`a` is adjacent to `b` right of `b`, if `a` and `b` do _not_ overlap,\nand there are no points between `a.left` and `b.right`.\n\n    # a:     [---)\n    # b: [---)\n    # r: true\n\n    # a:     [---)\n    # b: [---]\n    # r: false (overlaps)\n\n    # a:        (---)\n    # b: (---)\n    # r: false (points exist between a.left and b.right)","ref":"Interval.html#adjacent_right_of?/2"},{"type":"function","title":"Examples - Interval.adjacent_right_of?/2","doc":"iex> adjacent_right_of?(new(module: Interval.IntegerInterval, left: 2, right: 3), new(module: Interval.IntegerInterval, left: 1, right: 2))\n    true\n\n    iex> adjacent_right_of?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    false\n\n    iex> adjacent_right_of?(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 3, right: 4))\n    false\n\n    iex> adjacent_right_of?(new(module: Interval.IntegerInterval, left: 3), new(module: Interval.IntegerInterval, right: 2, bounds: \"]\"))\n    true","ref":"Interval.html#adjacent_right_of?/2-examples"},{"type":"type","title":"Interval.bound/0","doc":"The bound type of an endpoint.","ref":"Interval.html#t:bound/0"},{"type":"function","title":"Interval.compare_bounds/4","doc":"Compare the left/right side of `a` with the left/right side of `b`\n\nReturns `:lt | :gt | :eq` depending on `a`s relationship to `b`.\n\nOther interval operations use this function as primitive.","ref":"Interval.html#compare_bounds/4"},{"type":"function","title":"Interval.contains?/2","doc":"Does `a` contain `b`?\n\n`a` contains `b` of all points in `b` is also in `a`.\n\nFor an interval `a` to contain an interval `b`, all points\nin `b` must be contained in `a`:\n\n    # a: [-------]\n    # b:   [---]\n    # r: true\n\n    # a: [---]\n    # b: [---]\n    # r: true\n\n    # a: [---]\n    # b: (---)\n    # r: true\n\n    # a: (---)\n    # b: [---]\n    # r: false\n\n    # a:   [---]\n    # b: [-------]\n    # r: false\n\nThis means that `a.left` is less than `b.left` (or unbounded), and `a.right` is greater than\n`b.right` (or unbounded)\n\nIf `a` and `b`'s point match, then `b` is \"in\" `a` if `a` and `b` share bound types.\n\nE.g. if `a.left` and `b.left` matches, then `a` contains `b` if both `a` and `b`'s\n`left` is inclusive or exclusive.\n\nIf either of `b` endpoints are unbounded, then `a` only contains `b`\nif the corresponding endpoint in `a` is also unbounded.","ref":"Interval.html#contains?/2"},{"type":"function","title":"Examples - Interval.contains?/2","doc":"iex> contains?(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 1, right: 2))\n    true\n\n    iex> contains?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 3))\n    true\n\n    iex> contains?(new(module: Interval.IntegerInterval, left: 2, right: 3), new(module: Interval.IntegerInterval, left: 1, right: 4))\n    false\n\n    iex> contains?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 1, right: 2))\n    true\n\n    iex> contains?(new(module: Interval.IntegerInterval, left: 1, right: 2, bounds: \"()\"), new(module: Interval.IntegerInterval, left: 1, right: 3))\n    false\n\n    iex> contains?(new(module: Interval.IntegerInterval, right: 1), new(module: Interval.IntegerInterval, left: 0, right: 1))\n    true","ref":"Interval.html#contains?/2-examples"},{"type":"function","title":"Interval.contains_point?/2","doc":"Does `a` contain the point `x`?","ref":"Interval.html#contains_point?/2"},{"type":"function","title":"Examples - Interval.contains_point?/2","doc":"iex> contains_point?(new(module: Interval.IntegerInterval, left: 1, right: 2), 0)\n    false\n\n    iex> contains_point?(new(module: Interval.IntegerInterval, left: 1, right: 2), 1)\n    true","ref":"Interval.html#contains_point?/2-examples"},{"type":"function","title":"Interval.difference/2","doc":"Computes the difference between `a` and `b` by subtracting all points in `b` from `a`.\n\n`b` must not be contained in `a` in such a way that the difference would not be a single interval.","ref":"Interval.html#difference/2"},{"type":"function","title":"Examples: - Interval.difference/2","doc":"Discrete:\n\n    # a: [-----)\n    # b:     [-----)\n    # c: [---)\n    iex> difference(Interval.IntegerInterval.new(1, 4), Interval.IntegerInterval.new(3, 5))\n    Interval.IntegerInterval.new(1, 3)\n\n    # a:     [-----)\n    # b: [-----)\n    # c:       [---)\n    iex> difference(Interval.IntegerInterval.new(3, 5), Interval.IntegerInterval.new(1, 4))\n    Interval.IntegerInterval.new(4, 5)\n\nContinuous:\n\n    # a: [------)\n    # b:     [-----)\n    # c: [---)\n    iex> difference(Interval.FloatInterval.new(1.0, 4.0), Interval.FloatInterval.new(3.0, 5.0))\n    Interval.FloatInterval.new(1.0, 3.0)\n\n    # a: [-----)\n    # b:     (-----)\n    # c: [---]\n    iex> difference(Interval.FloatInterval.new(1.0, 4.0), Interval.FloatInterval.new(3.0, 5.0, \"()\"))\n    Interval.FloatInterval.new(1.0, 3.0, \"[]\")","ref":"Interval.html#difference/2-examples"},{"type":"function","title":"Interval.empty?/1","doc":"Is the interval empty?\n\nAn empty interval is an interval that represents no points.\nAny interval containing no points is considered empty.\n\nAn unbounded interval is never empty.\n\nFor continuous points, the interval is empty when the left and\nright points are identical, and the point is not included in the interval.\n\nFor discrete points, the interval is empty when the left and right point\nisn't inclusive, and there are no points between the left and right point.","ref":"Interval.html#empty?/1"},{"type":"function","title":"Examples - Interval.empty?/1","doc":"iex> empty?(new(module: Interval.IntegerInterval, left: 0, right: 0))\n    true\n\n    iex> empty?(new(module: Interval.FloatInterval, left: 1.0))\n    false\n\n    iex> empty?(new(module: Interval.IntegerInterval, left: 1, right: 2))\n    false","ref":"Interval.html#empty?/1-examples"},{"type":"type","title":"Interval.endpoint/1","doc":"An endpoint of an interval.\n\nCan be either\n- `:empty` representing an empty interval (both endpoints will be empty)\n- `:unbounded` representing an unbounded endpoint\n- `{bound(), t}` representing a bounded endpoint","ref":"Interval.html#t:endpoint/1"},{"type":"function","title":"Interval.exclusive_left?/1","doc":"Is the interval left-exclusive?\n\nThe interval is left-exclusive if the left endpoint value is excluded from the interval.\n\n> #### Note {: .info}\n> Discrete intervals (like `Interval.IntegerInterval` and `Interval.DateInterval`) are always normalized\n> to be left-inclusive right-exclusive (`[)`).\n\n\n    iex> exclusive_left?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[]\"))\n    false\n\n    iex> exclusive_left?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"(]\"))\n    true\n\n    iex> exclusive_left?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"()\"))\n    true","ref":"Interval.html#exclusive_left?/1"},{"type":"function","title":"Interval.exclusive_right?/1","doc":"Is the interval right-exclusive?\n\nThe interval is right-exclusive if the right endpoint value is excluded from the interval.\n\n> #### Note {: .info}\n> Discrete intervals (like `Interval.IntegerInterval` and `Interval.DateInterval`) are always normalized\n> to be left-inclusive right-exclusive (`[)`).\n\n\n    iex> exclusive_right?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[]\"))\n    false\n\n    iex> exclusive_right?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[)\"))\n    true\n\n    iex> exclusive_right?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"()\"))\n    true","ref":"Interval.html#exclusive_right?/1"},{"type":"function","title":"Interval.inclusive_left?/1","doc":"Is the interval left-inclusive?\n\nThe interval is left-inclusive if the left endpoint\nvalue is included in the interval.\n\n> #### Note {: .info}\n> Discrete intervals (like `Interval.IntegerInterval` and `Interval.DateInterval`) are always normalized\n> to be left-inclusive right-exclusive (`[)`).\n\n\n    iex> inclusive_left?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[]\"))\n    true\n\n    iex> inclusive_left?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[)\"))\n    true\n\n    iex> inclusive_left?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"()\"))\n    false","ref":"Interval.html#inclusive_left?/1"},{"type":"function","title":"Interval.inclusive_right?/1","doc":"Is the interval right-inclusive?\n\nThe interval is right-inclusive if the right endpoint\nvalue is included in the interval.\n\n> #### Note {: .info}\n> Discrete intervals (like `Interval.IntegerInterval` and `Interval.DateInterval`) are always normalized\n> to be left-inclusive right-exclusive (`[)`).\n\n\n    iex> inclusive_right?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[]\"))\n    true\n\n    iex> inclusive_right?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"[)\"))\n    false\n\n    iex> inclusive_right?(new(module: Interval.FloatInterval, left: 1.0, right: 2.0, bounds: \"()\"))\n    false","ref":"Interval.html#inclusive_right?/1"},{"type":"function","title":"Interval.intersection/2","doc":"Compute the intersection between `a` and `b`.\n\nThe intersection contains all of the points that are both in `a` and `b`.\n\nIf either `a` or `b` are empty, the returned interval will be empty.\n\n    # a: [----]\n    # b:    [----]\n    # r:    [-]\n\n    # a: (----)\n    # b:    (----)\n    # r:    (-)\n\n    # a: [----)\n    # b:    [----)\n    # r:    [-)","ref":"Interval.html#intersection/2"},{"type":"function","title":"Examples: - Interval.intersection/2","doc":"Discrete:\n\n    # a: [----)\n    # b:    [----)\n    # c:    [-)\n    iex> intersection(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    new(module: Interval.IntegerInterval, left: 2, right: 3)\n\nContinuous:\n\n    # a: [----)\n    # b:    [----)\n    # c:    [-)\n    iex> intersection(new(module: Interval.FloatInterval, left: 1.0, right: 3.0), new(module: Interval.FloatInterval, left: 2.0, right: 4.0))\n    new(module: Interval.FloatInterval, left: 2.0, right: 3.0)\n\n    # a: (----)\n    # b:    (----)\n    # c:    (-)\n    iex> intersection(\n    ...>   new(module: Interval.FloatInterval, left: 1.0, right: 3.0, bounds: \"()\"),\n    ...>   new(module: Interval.FloatInterval, left: 2.0, right: 4.0, bounds: \"()\")\n    ...> )\n    new(module: Interval.FloatInterval, left: 2.0, right: 3.0, bounds: \"()\")\n\n    # a: [-----)\n    # b:   [-------\n    # c:   [---)\n    iex> intersection(new(module: Interval.FloatInterval, left: 1.0, right: 3.0), new(module: Interval.FloatInterval, left: 2.0))\n    new(module: Interval.FloatInterval, left: 2.0, right: 3.0)","ref":"Interval.html#intersection/2-examples"},{"type":"function","title":"Interval.left/1","doc":"Return the left point.\n\nThis function always returns nil when no point exist.\nUse the functions `empty?/1`, `inclusive_left?/1` and `unbounded_left?/1`\nto check for the meaning of the point.","ref":"Interval.html#left/1"},{"type":"function","title":"Example - Interval.left/1","doc":"iex> left(new(module: Interval.IntegerInterval, left: 1, right: 2))\n    1","ref":"Interval.html#left/1-example"},{"type":"function","title":"Interval.new/1","doc":"Create a new interval.","ref":"Interval.html#new/1"},{"type":"function","title":"Options - Interval.new/1","doc":"- `left` The left (or lower) endpoint value of the interval (default: `:unbounded`)\n- `right` The right (or upper) endpoint value of the interval (default: `:unbounded`)\n- `bounds` The bound mode to use (default: `\"[)\"`)\n- `empty` If set to `true`, the interval will be empty (default: `false`)\n- `module` The interval implementation to use.\n   When calling `new/1` from an `Interval.Behaviour` this is inferred.\n\nSpecifying `left` or `right` as `nil` will be interpreted as `:unbounded`.\nThe endpoint will also be considered unbounded if the `bounds` explicitly sets it as unbounded.\n\nSpecifying `left` or `right` as `:empty` will create an empty interval.","ref":"Interval.html#new/1-options"},{"type":"function","title":"Bounds - Interval.new/1","doc":"The `bounds` options contains the left and right bound mode to use.\nThe bound can be inclusive, exclusive or unbounded.\n\nThe following valid bound values are supported:\n\n- `\"[)\"` left-inclusive, right-exclusive (default)\n- `\"(]\"` left-exclusive, right-inclusive\n- `\"[]\"` left-inclusive, right-inclusive\n- `\"()\"` left-exclusive, right-exclusive\n- `\")\"`  left-unbounded, right-exclusive\n- `\"]\"`  left-unbounded, right-inclusive\n- `\"(\"`  left-exclusive, right-unbounded\n- `\"[\"`  left-inclusive, right-unbounded","ref":"Interval.html#new/1-bounds"},{"type":"function","title":"Examples - Interval.new/1","doc":"iex> new(module: Interval.IntegerInterval)\n\n    iex> new(module: Interval.IntegerInterval, empty: true)\n\n    iex> new(module: Interval.IntegerInterval, left: 1)\n\n    iex> new(module: Interval.IntegerInterval, left: 1, right: 1, bounds: \"[]\")\n\n    iex> new(module: Interval.IntegerInterval, left: 10, right: 20, bounds: \"()\")","ref":"Interval.html#new/1-examples"},{"type":"function","title":"Interval.overlaps?/2","doc":"Does `a` overlap with `b`?\n\n`a` overlaps with `b` if any point in `a` is also in `b`.\n\n    # a: [---)\n    # b:   [---)\n    # r: true\n\n    # a: [---)\n    # b:     [---)\n    # r: false\n\n    # a: [---]\n    # b:     [---]\n    # r: true\n\n    # a: (---)\n    # b:     (---)\n    # r: false\n\n    # a: [---)\n    # b:        [---)\n    # r: false","ref":"Interval.html#overlaps?/2"},{"type":"function","title":"Examples - Interval.overlaps?/2","doc":"# [--a--)\n    #     [--b--)\n\n    iex> overlaps?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    true\n\n\n    # [--a--)\n    #       [--b--)\n\n    iex> overlaps?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 3, right: 5))\n    false\n\n\n    # [--a--]\n    #       [--b--]\n\n    iex> overlaps?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    true\n\n\n    # (--a--)\n    #       (--b--)\n\n    iex> overlaps?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 3, right: 5))\n    false\n\n\n    # [--a--)\n    #          [--b--)\n\n    iex> overlaps?(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 3, right: 4))\n    false","ref":"Interval.html#overlaps?/2-examples"},{"type":"function","title":"Interval.partition/2","doc":"Partition an interval `a` into 3 intervals using  `x`:\n\n- The interval with all points from `a` where `a` < `x`\n- The interval with `x`\n- The interval with all points from `a` where `a` > `x`\n\nIf `x` is not in `a` this function returns an empty list.\n\nNote: Since 2.0.0, `x` can be a point _or_ an interval.\nWhen `x` is a point, the middle interval will be an interval such that `[x,x]`.\n\nIf there are no points in a to the left of `x`, an empty interval is returned for the left side.\nThe same of course applies to the right side of `x`.","ref":"Interval.html#partition/2"},{"type":"function","title":"Examples - Interval.partition/2","doc":"iex> partition(Interval.IntegerInterval.new(1, 5, \"[]\"), 3)\n    [\n      Interval.IntegerInterval.new(1, 3, \"[)\"),\n      Interval.IntegerInterval.new(3, 3, \"[]\"),\n      Interval.IntegerInterval.new(3, 5, \"(]\")\n    ]\n\n    iex> partition(Interval.IntegerInterval.new(1, 5), -10)\n    []\n\n    iex> partition(Interval.IntegerInterval.new(1, 6), Interval.IntegerInterval.new(3, 4))\n    [\n      Interval.IntegerInterval.new(1, 3, \"[)\"),\n      Interval.IntegerInterval.new(3, 4, \"[)\"),\n      Interval.IntegerInterval.new(4, 6, \"[)\")\n    ]\n\n    iex> partition(Interval.FloatInterval.new(1.0, 6.0), Interval.FloatInterval.new(1.0, 3.0, \"[]\"))\n    [\n      Interval.FloatInterval.new(1.0, 1.0, \"[)\"),\n      Interval.FloatInterval.new(1.0, 3.0, \"[]\"),\n      Interval.FloatInterval.new(3.0, 6.0, \"()\")\n    ]","ref":"Interval.html#partition/2-examples"},{"type":"type","title":"Interval.point/0","doc":"A point in an interval.","ref":"Interval.html#t:point/0"},{"type":"function","title":"Interval.right/1","doc":"Return the right point.\n\nThis function always returns nil when no point exist.\nUse the functions `empty?/1`, `inclusive_right?/1` and `unbounded_right?/1`\nto check for the meaning of the point.","ref":"Interval.html#right/1"},{"type":"function","title":"Example - Interval.right/1","doc":"iex> right(new(module: Interval.IntegerInterval, left: 1, right: 2))\n    2","ref":"Interval.html#right/1-example"},{"type":"type","title":"Interval.strbounds/0","doc":"Options are:  \"[]\" | \"()\" | \"(]\" | \"[)\" | \"[\" | \"]\" | \"(\" | \")\" | \"\"","ref":"Interval.html#t:strbounds/0"},{"type":"function","title":"Interval.strictly_left_of?/2","doc":"Is `a` strictly left of `b`.\n\n`a` is strictly left of `b` if no point in `a` is in `b`,\nand all points in `a` is left (<) of all points in `b`.","ref":"Interval.html#strictly_left_of?/2"},{"type":"function","title":"Examples - Interval.strictly_left_of?/2","doc":"# a: [---)\n    # b:     [---)\n    # r: true\n\n    # a: [---)\n    # b:        [---)\n    # r: true\n\n    # a: [---)\n    # b:    [---)\n    # r: false (overlaps)\n\n    iex> strictly_left_of?(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 3, right: 4))\n    true\n\n    iex> strictly_left_of?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    false\n\n    iex> strictly_left_of?(new(module: Interval.IntegerInterval, left: 3, right: 4), new(module: Interval.IntegerInterval, left: 1, right: 2))\n    false","ref":"Interval.html#strictly_left_of?/2-examples"},{"type":"function","title":"Interval.strictly_right_of?/2","doc":"Is `a` strictly right of `b`.\n\n`a` is strictly right of `b` if no point in `a` is in `b`,\nand all points in `a` is right (>) of all points in `b`.","ref":"Interval.html#strictly_right_of?/2"},{"type":"function","title":"Examples - Interval.strictly_right_of?/2","doc":"# a:     [---)\n    # b: [---)\n    # r: true\n\n    # a:        [---)\n    # b: [---)\n    # r: true\n\n    # a:    [---)\n    # b: [---)\n    # r: false (overlaps)\n\n    iex> strictly_right_of?(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 3, right: 4))\n    false\n\n    iex> strictly_right_of?(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    false\n\n    iex> strictly_right_of?(new(module: Interval.IntegerInterval, left: 3, right: 4), new(module: Interval.IntegerInterval, left: 1, right: 2))\n    true","ref":"Interval.html#strictly_right_of?/2-examples"},{"type":"type","title":"Interval.t/0","doc":"Shorthand for `t(any())`","ref":"Interval.html#t:t/0"},{"type":"type","title":"Interval.t/1","doc":"An interval struct, representing all points between\ntwo endpoints.\n\nThe struct has two fields: `left` and `right`,\nrepresenting the left (lower) and right (upper) points\nin the interval.\n\nIf either left or right is set to `:empty`, the both must be\nset to `:empty`.\n\nThe specific struct type depends on the interval implementation,\nbut the `left` and `right` field is always present, all will\nbe manipulated by the `Interval` module regardless of the interval\nimplementation.","ref":"Interval.html#t:t/1"},{"type":"function","title":"Interval.unbounded_left?/1","doc":"Check if the interval is left-unbounded.\n\nThe interval is left-unbounded if all points\nleft of the right bound is included in this interval.","ref":"Interval.html#unbounded_left?/1"},{"type":"function","title":"Examples - Interval.unbounded_left?/1","doc":"iex> unbounded_left?(new(module: Interval.IntegerInterval))\n    true\n\n    iex> unbounded_left?(new(module: Interval.IntegerInterval, right: 2))\n    true\n\n    iex> unbounded_left?(new(module: Interval.IntegerInterval, left: 1, right: 2))\n    false","ref":"Interval.html#unbounded_left?/1-examples"},{"type":"function","title":"Interval.unbounded_right?/1","doc":"Check if the interval is right-unbounded.\n\nThe interval is right-unbounded if all points\nright of the left bound is included in this interval.","ref":"Interval.html#unbounded_right?/1"},{"type":"function","title":"Examples - Interval.unbounded_right?/1","doc":"iex> unbounded_right?(new(module: Interval.IntegerInterval, right: 1))\n    false\n\n    iex> unbounded_right?(new(module: Interval.IntegerInterval))\n    true\n\n    iex> unbounded_right?(new(module: Interval.IntegerInterval, left: 1))\n    true","ref":"Interval.html#unbounded_right?/1-examples"},{"type":"function","title":"Interval.union/2","doc":"Computes the union of `a` and `b`.\n\nThe union contains all of the points that are either in `a` or `b`.\n\nIf either `a` or `b` are empty, the returned interval will be the non-empty interval.\n\n    # a: [---)\n    # b:   [---)\n    # r: [-----)","ref":"Interval.html#union/2"},{"type":"function","title":"Examples - Interval.union/2","doc":"# [--A--)\n    #     [--B--)\n    # [----C----)\n\n    iex> union(new(module: Interval.IntegerInterval, left: 1, right: 3), new(module: Interval.IntegerInterval, left: 2, right: 4))\n    new(module: Interval.IntegerInterval, left: 1, right: 4)\n\n\n    # [-A-)\n    #     [-B-)\n    # [---C---)\n\n    iex> union(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 2, right: 3))\n    new(module: Interval.IntegerInterval, left: 1, right: 3)\n\n    iex> union(new(module: Interval.IntegerInterval, left: 1, right: 2), new(module: Interval.IntegerInterval, left: 3, right: 4))\n    ** (Interval.IntervalOperationError) cannot union non-overlapping non-adjacent intervals as the result would be non-contiguous","ref":"Interval.html#union/2-examples"},{"type":"behaviour","title":"Interval.Behaviour","doc":"Defines the Interval behaviour.\nYou'll usually want to use this behaviour by using\n\n    use Interval, type: MyType\n\nIn your own interval modules, instead of defining\nthe behaviour directly.","ref":"Interval.Behaviour.html"},{"type":"callback","title":"Interval.Behaviour.discrete?/0","doc":"Is this implementation of an interval considered discrete?\n\nThe interval is implicitly continuous if not discrete.","ref":"Interval.Behaviour.html#c:discrete?/0"},{"type":"callback","title":"Interval.Behaviour.new/1","doc":"Create a new `t:Interval.t/0`","ref":"Interval.Behaviour.html#c:new/1"},{"type":"callback","title":"Interval.Behaviour.new/3","doc":"Create a new interval with the specified left and right endpoints, and bounds.\n\nThis is a specialization of the more general `new/1`","ref":"Interval.Behaviour.html#c:new/3"},{"type":"type","title":"Interval.Behaviour.new_opt/0","doc":"","ref":"Interval.Behaviour.html#t:new_opt/0"},{"type":"type","title":"Interval.Behaviour.new_opts/0","doc":"","ref":"Interval.Behaviour.html#t:new_opts/0"},{"type":"callback","title":"Interval.Behaviour.point_compare/2","doc":"Compare two points, returning if `a == b`, `a > b` or `a < b`.","ref":"Interval.Behaviour.html#c:point_compare/2"},{"type":"callback","title":"Interval.Behaviour.point_normalize/1","doc":"Normalize a point to a canonical form. Returns :error if the point is invalid.","ref":"Interval.Behaviour.html#c:point_normalize/1"},{"type":"callback","title":"Interval.Behaviour.point_step/2","doc":"Step a discrete point `n` steps.\n\nIf `n` is negative, the point is stepped backwards.\nFor integers this is simply addition (`point + n`)","ref":"Interval.Behaviour.html#c:point_step/2"},{"type":"module","title":"Interval.DateInterval","doc":"Represents a discrete interval containing `Date`\n\nDefines a struct with two fields, `left` and `right`, representing the left and right endpoints of the interval.\nThe endpoint fields are of type `t:Interval.endpoint(Date)`\n\nThis module delegates most functionality to the `Interval` module.","ref":"Interval.DateInterval.html"},{"type":"function","title":"Interval.DateInterval.adjacent?/2","doc":"","ref":"Interval.DateInterval.html#adjacent?/2"},{"type":"function","title":"Interval.DateInterval.adjacent_left_of?/2","doc":"","ref":"Interval.DateInterval.html#adjacent_left_of?/2"},{"type":"function","title":"Interval.DateInterval.adjacent_right_of?/2","doc":"","ref":"Interval.DateInterval.html#adjacent_right_of?/2"},{"type":"function","title":"Interval.DateInterval.contains?/2","doc":"","ref":"Interval.DateInterval.html#contains?/2"},{"type":"function","title":"Interval.DateInterval.contains_point?/2","doc":"","ref":"Interval.DateInterval.html#contains_point?/2"},{"type":"function","title":"Interval.DateInterval.difference/2","doc":"","ref":"Interval.DateInterval.html#difference/2"},{"type":"function","title":"Interval.DateInterval.discrete?/0","doc":"","ref":"Interval.DateInterval.html#discrete?/0"},{"type":"function","title":"Interval.DateInterval.embed_as/1","doc":"","ref":"Interval.DateInterval.html#embed_as/1"},{"type":"function","title":"Interval.DateInterval.empty?/1","doc":"","ref":"Interval.DateInterval.html#empty?/1"},{"type":"function","title":"Interval.DateInterval.equal?/2","doc":"","ref":"Interval.DateInterval.html#equal?/2"},{"type":"function","title":"Interval.DateInterval.inclusive_left?/1","doc":"","ref":"Interval.DateInterval.html#inclusive_left?/1"},{"type":"function","title":"Interval.DateInterval.inclusive_right?/1","doc":"","ref":"Interval.DateInterval.html#inclusive_right?/1"},{"type":"function","title":"Interval.DateInterval.intersection/2","doc":"","ref":"Interval.DateInterval.html#intersection/2"},{"type":"function","title":"Interval.DateInterval.left/1","doc":"","ref":"Interval.DateInterval.html#left/1"},{"type":"function","title":"Interval.DateInterval.new/1","doc":"","ref":"Interval.DateInterval.html#new/1"},{"type":"function","title":"Interval.DateInterval.new/3","doc":"","ref":"Interval.DateInterval.html#new/3"},{"type":"function","title":"Interval.DateInterval.overlaps?/2","doc":"","ref":"Interval.DateInterval.html#overlaps?/2"},{"type":"function","title":"Interval.DateInterval.partition/2","doc":"","ref":"Interval.DateInterval.html#partition/2"},{"type":"type","title":"Interval.DateInterval.point_type/0","doc":"","ref":"Interval.DateInterval.html#t:point_type/0"},{"type":"function","title":"Interval.DateInterval.right/1","doc":"","ref":"Interval.DateInterval.html#right/1"},{"type":"function","title":"Interval.DateInterval.strictly_left_of?/2","doc":"","ref":"Interval.DateInterval.html#strictly_left_of?/2"},{"type":"function","title":"Interval.DateInterval.strictly_right_of?/2","doc":"","ref":"Interval.DateInterval.html#strictly_right_of?/2"},{"type":"type","title":"Interval.DateInterval.t/0","doc":"An interval of point type `Date`","ref":"Interval.DateInterval.html#t:t/0"},{"type":"function","title":"Interval.DateInterval.unbounded_left?/1","doc":"","ref":"Interval.DateInterval.html#unbounded_left?/1"},{"type":"function","title":"Interval.DateInterval.unbounded_right?/1","doc":"","ref":"Interval.DateInterval.html#unbounded_right?/1"},{"type":"function","title":"Interval.DateInterval.union/2","doc":"","ref":"Interval.DateInterval.html#union/2"},{"type":"module","title":"Interval.DateTimeInterval","doc":"Represents a continuous interval containing `DateTime`\n\nDefines a struct with two fields, `left` and `right`, representing the left and right endpoints of the interval.\nThe endpoint fields are of type `t:Interval.endpoint(DateTime)`\n\nThis module delegates most functionality to the `Interval` module.","ref":"Interval.DateTimeInterval.html"},{"type":"function","title":"Interval.DateTimeInterval.adjacent?/2","doc":"","ref":"Interval.DateTimeInterval.html#adjacent?/2"},{"type":"function","title":"Interval.DateTimeInterval.adjacent_left_of?/2","doc":"","ref":"Interval.DateTimeInterval.html#adjacent_left_of?/2"},{"type":"function","title":"Interval.DateTimeInterval.adjacent_right_of?/2","doc":"","ref":"Interval.DateTimeInterval.html#adjacent_right_of?/2"},{"type":"function","title":"Interval.DateTimeInterval.contains?/2","doc":"","ref":"Interval.DateTimeInterval.html#contains?/2"},{"type":"function","title":"Interval.DateTimeInterval.contains_point?/2","doc":"","ref":"Interval.DateTimeInterval.html#contains_point?/2"},{"type":"function","title":"Interval.DateTimeInterval.difference/2","doc":"","ref":"Interval.DateTimeInterval.html#difference/2"},{"type":"function","title":"Interval.DateTimeInterval.discrete?/0","doc":"","ref":"Interval.DateTimeInterval.html#discrete?/0"},{"type":"function","title":"Interval.DateTimeInterval.embed_as/1","doc":"","ref":"Interval.DateTimeInterval.html#embed_as/1"},{"type":"function","title":"Interval.DateTimeInterval.empty?/1","doc":"","ref":"Interval.DateTimeInterval.html#empty?/1"},{"type":"function","title":"Interval.DateTimeInterval.equal?/2","doc":"","ref":"Interval.DateTimeInterval.html#equal?/2"},{"type":"function","title":"Interval.DateTimeInterval.inclusive_left?/1","doc":"","ref":"Interval.DateTimeInterval.html#inclusive_left?/1"},{"type":"function","title":"Interval.DateTimeInterval.inclusive_right?/1","doc":"","ref":"Interval.DateTimeInterval.html#inclusive_right?/1"},{"type":"function","title":"Interval.DateTimeInterval.intersection/2","doc":"","ref":"Interval.DateTimeInterval.html#intersection/2"},{"type":"function","title":"Interval.DateTimeInterval.left/1","doc":"","ref":"Interval.DateTimeInterval.html#left/1"},{"type":"function","title":"Interval.DateTimeInterval.new/1","doc":"","ref":"Interval.DateTimeInterval.html#new/1"},{"type":"function","title":"Interval.DateTimeInterval.new/3","doc":"","ref":"Interval.DateTimeInterval.html#new/3"},{"type":"function","title":"Interval.DateTimeInterval.overlaps?/2","doc":"","ref":"Interval.DateTimeInterval.html#overlaps?/2"},{"type":"function","title":"Interval.DateTimeInterval.partition/2","doc":"","ref":"Interval.DateTimeInterval.html#partition/2"},{"type":"function","title":"Interval.DateTimeInterval.point_step/2","doc":"","ref":"Interval.DateTimeInterval.html#point_step/2"},{"type":"type","title":"Interval.DateTimeInterval.point_type/0","doc":"","ref":"Interval.DateTimeInterval.html#t:point_type/0"},{"type":"function","title":"Interval.DateTimeInterval.right/1","doc":"","ref":"Interval.DateTimeInterval.html#right/1"},{"type":"function","title":"Interval.DateTimeInterval.strictly_left_of?/2","doc":"","ref":"Interval.DateTimeInterval.html#strictly_left_of?/2"},{"type":"function","title":"Interval.DateTimeInterval.strictly_right_of?/2","doc":"","ref":"Interval.DateTimeInterval.html#strictly_right_of?/2"},{"type":"type","title":"Interval.DateTimeInterval.t/0","doc":"An interval of point type `DateTime`","ref":"Interval.DateTimeInterval.html#t:t/0"},{"type":"function","title":"Interval.DateTimeInterval.unbounded_left?/1","doc":"","ref":"Interval.DateTimeInterval.html#unbounded_left?/1"},{"type":"function","title":"Interval.DateTimeInterval.unbounded_right?/1","doc":"","ref":"Interval.DateTimeInterval.html#unbounded_right?/1"},{"type":"function","title":"Interval.DateTimeInterval.union/2","doc":"","ref":"Interval.DateTimeInterval.html#union/2"},{"type":"module","title":"Interval.DecimalInterval","doc":"Represents a continuous interval containing `Decimal`\n\nDefines a struct with two fields, `left` and `right`, representing the left and right endpoints of the interval.\nThe endpoint fields are of type `t:Interval.endpoint(Decimal)`\n\nThis module delegates most functionality to the `Interval` module.","ref":"Interval.DecimalInterval.html"},{"type":"function","title":"Interval.DecimalInterval.adjacent?/2","doc":"","ref":"Interval.DecimalInterval.html#adjacent?/2"},{"type":"function","title":"Interval.DecimalInterval.adjacent_left_of?/2","doc":"","ref":"Interval.DecimalInterval.html#adjacent_left_of?/2"},{"type":"function","title":"Interval.DecimalInterval.adjacent_right_of?/2","doc":"","ref":"Interval.DecimalInterval.html#adjacent_right_of?/2"},{"type":"function","title":"Interval.DecimalInterval.contains?/2","doc":"","ref":"Interval.DecimalInterval.html#contains?/2"},{"type":"function","title":"Interval.DecimalInterval.contains_point?/2","doc":"","ref":"Interval.DecimalInterval.html#contains_point?/2"},{"type":"function","title":"Interval.DecimalInterval.difference/2","doc":"","ref":"Interval.DecimalInterval.html#difference/2"},{"type":"function","title":"Interval.DecimalInterval.discrete?/0","doc":"","ref":"Interval.DecimalInterval.html#discrete?/0"},{"type":"function","title":"Interval.DecimalInterval.embed_as/1","doc":"","ref":"Interval.DecimalInterval.html#embed_as/1"},{"type":"function","title":"Interval.DecimalInterval.empty?/1","doc":"","ref":"Interval.DecimalInterval.html#empty?/1"},{"type":"function","title":"Interval.DecimalInterval.equal?/2","doc":"","ref":"Interval.DecimalInterval.html#equal?/2"},{"type":"function","title":"Interval.DecimalInterval.inclusive_left?/1","doc":"","ref":"Interval.DecimalInterval.html#inclusive_left?/1"},{"type":"function","title":"Interval.DecimalInterval.inclusive_right?/1","doc":"","ref":"Interval.DecimalInterval.html#inclusive_right?/1"},{"type":"function","title":"Interval.DecimalInterval.intersection/2","doc":"","ref":"Interval.DecimalInterval.html#intersection/2"},{"type":"function","title":"Interval.DecimalInterval.left/1","doc":"","ref":"Interval.DecimalInterval.html#left/1"},{"type":"function","title":"Interval.DecimalInterval.new/1","doc":"","ref":"Interval.DecimalInterval.html#new/1"},{"type":"function","title":"Interval.DecimalInterval.new/3","doc":"","ref":"Interval.DecimalInterval.html#new/3"},{"type":"function","title":"Interval.DecimalInterval.overlaps?/2","doc":"","ref":"Interval.DecimalInterval.html#overlaps?/2"},{"type":"function","title":"Interval.DecimalInterval.partition/2","doc":"","ref":"Interval.DecimalInterval.html#partition/2"},{"type":"function","title":"Interval.DecimalInterval.point_step/2","doc":"","ref":"Interval.DecimalInterval.html#point_step/2"},{"type":"type","title":"Interval.DecimalInterval.point_type/0","doc":"","ref":"Interval.DecimalInterval.html#t:point_type/0"},{"type":"function","title":"Interval.DecimalInterval.right/1","doc":"","ref":"Interval.DecimalInterval.html#right/1"},{"type":"function","title":"Interval.DecimalInterval.strictly_left_of?/2","doc":"","ref":"Interval.DecimalInterval.html#strictly_left_of?/2"},{"type":"function","title":"Interval.DecimalInterval.strictly_right_of?/2","doc":"","ref":"Interval.DecimalInterval.html#strictly_right_of?/2"},{"type":"type","title":"Interval.DecimalInterval.t/0","doc":"An interval of point type `Decimal`","ref":"Interval.DecimalInterval.html#t:t/0"},{"type":"function","title":"Interval.DecimalInterval.unbounded_left?/1","doc":"","ref":"Interval.DecimalInterval.html#unbounded_left?/1"},{"type":"function","title":"Interval.DecimalInterval.unbounded_right?/1","doc":"","ref":"Interval.DecimalInterval.html#unbounded_right?/1"},{"type":"function","title":"Interval.DecimalInterval.union/2","doc":"","ref":"Interval.DecimalInterval.html#union/2"},{"type":"module","title":"Interval.FloatInterval","doc":"Represents a continuous interval containing `Float`\n\nDefines a struct with two fields, `left` and `right`, representing the left and right endpoints of the interval.\nThe endpoint fields are of type `t:Interval.endpoint(Float)`\n\nThis module delegates most functionality to the `Interval` module.","ref":"Interval.FloatInterval.html"},{"type":"function","title":"Interval.FloatInterval.adjacent?/2","doc":"","ref":"Interval.FloatInterval.html#adjacent?/2"},{"type":"function","title":"Interval.FloatInterval.adjacent_left_of?/2","doc":"","ref":"Interval.FloatInterval.html#adjacent_left_of?/2"},{"type":"function","title":"Interval.FloatInterval.adjacent_right_of?/2","doc":"","ref":"Interval.FloatInterval.html#adjacent_right_of?/2"},{"type":"function","title":"Interval.FloatInterval.contains?/2","doc":"","ref":"Interval.FloatInterval.html#contains?/2"},{"type":"function","title":"Interval.FloatInterval.contains_point?/2","doc":"","ref":"Interval.FloatInterval.html#contains_point?/2"},{"type":"function","title":"Interval.FloatInterval.difference/2","doc":"","ref":"Interval.FloatInterval.html#difference/2"},{"type":"function","title":"Interval.FloatInterval.discrete?/0","doc":"","ref":"Interval.FloatInterval.html#discrete?/0"},{"type":"function","title":"Interval.FloatInterval.embed_as/1","doc":"","ref":"Interval.FloatInterval.html#embed_as/1"},{"type":"function","title":"Interval.FloatInterval.empty?/1","doc":"","ref":"Interval.FloatInterval.html#empty?/1"},{"type":"function","title":"Interval.FloatInterval.equal?/2","doc":"","ref":"Interval.FloatInterval.html#equal?/2"},{"type":"function","title":"Interval.FloatInterval.inclusive_left?/1","doc":"","ref":"Interval.FloatInterval.html#inclusive_left?/1"},{"type":"function","title":"Interval.FloatInterval.inclusive_right?/1","doc":"","ref":"Interval.FloatInterval.html#inclusive_right?/1"},{"type":"function","title":"Interval.FloatInterval.intersection/2","doc":"","ref":"Interval.FloatInterval.html#intersection/2"},{"type":"function","title":"Interval.FloatInterval.left/1","doc":"","ref":"Interval.FloatInterval.html#left/1"},{"type":"function","title":"Interval.FloatInterval.new/1","doc":"","ref":"Interval.FloatInterval.html#new/1"},{"type":"function","title":"Interval.FloatInterval.new/3","doc":"","ref":"Interval.FloatInterval.html#new/3"},{"type":"function","title":"Interval.FloatInterval.overlaps?/2","doc":"","ref":"Interval.FloatInterval.html#overlaps?/2"},{"type":"function","title":"Interval.FloatInterval.partition/2","doc":"","ref":"Interval.FloatInterval.html#partition/2"},{"type":"function","title":"Interval.FloatInterval.point_compare/2","doc":"","ref":"Interval.FloatInterval.html#point_compare/2"},{"type":"function","title":"Interval.FloatInterval.point_normalize/1","doc":"","ref":"Interval.FloatInterval.html#point_normalize/1"},{"type":"function","title":"Interval.FloatInterval.point_step/2","doc":"","ref":"Interval.FloatInterval.html#point_step/2"},{"type":"type","title":"Interval.FloatInterval.point_type/0","doc":"","ref":"Interval.FloatInterval.html#t:point_type/0"},{"type":"function","title":"Interval.FloatInterval.right/1","doc":"","ref":"Interval.FloatInterval.html#right/1"},{"type":"function","title":"Interval.FloatInterval.strictly_left_of?/2","doc":"","ref":"Interval.FloatInterval.html#strictly_left_of?/2"},{"type":"function","title":"Interval.FloatInterval.strictly_right_of?/2","doc":"","ref":"Interval.FloatInterval.html#strictly_right_of?/2"},{"type":"type","title":"Interval.FloatInterval.t/0","doc":"An interval of point type `Float`","ref":"Interval.FloatInterval.html#t:t/0"},{"type":"function","title":"Interval.FloatInterval.unbounded_left?/1","doc":"","ref":"Interval.FloatInterval.html#unbounded_left?/1"},{"type":"function","title":"Interval.FloatInterval.unbounded_right?/1","doc":"","ref":"Interval.FloatInterval.html#unbounded_right?/1"},{"type":"function","title":"Interval.FloatInterval.union/2","doc":"","ref":"Interval.FloatInterval.html#union/2"},{"type":"module","title":"Interval.IntegerInterval","doc":"Represents a discrete interval containing `Integer`\n\nDefines a struct with two fields, `left` and `right`, representing the left and right endpoints of the interval.\nThe endpoint fields are of type `t:Interval.endpoint(Integer)`\n\nThis module delegates most functionality to the `Interval` module.","ref":"Interval.IntegerInterval.html"},{"type":"function","title":"Interval.IntegerInterval.adjacent?/2","doc":"","ref":"Interval.IntegerInterval.html#adjacent?/2"},{"type":"function","title":"Interval.IntegerInterval.adjacent_left_of?/2","doc":"","ref":"Interval.IntegerInterval.html#adjacent_left_of?/2"},{"type":"function","title":"Interval.IntegerInterval.adjacent_right_of?/2","doc":"","ref":"Interval.IntegerInterval.html#adjacent_right_of?/2"},{"type":"function","title":"Interval.IntegerInterval.contains?/2","doc":"","ref":"Interval.IntegerInterval.html#contains?/2"},{"type":"function","title":"Interval.IntegerInterval.contains_point?/2","doc":"","ref":"Interval.IntegerInterval.html#contains_point?/2"},{"type":"function","title":"Interval.IntegerInterval.difference/2","doc":"","ref":"Interval.IntegerInterval.html#difference/2"},{"type":"function","title":"Interval.IntegerInterval.discrete?/0","doc":"","ref":"Interval.IntegerInterval.html#discrete?/0"},{"type":"function","title":"Interval.IntegerInterval.embed_as/1","doc":"","ref":"Interval.IntegerInterval.html#embed_as/1"},{"type":"function","title":"Interval.IntegerInterval.empty?/1","doc":"","ref":"Interval.IntegerInterval.html#empty?/1"},{"type":"function","title":"Interval.IntegerInterval.equal?/2","doc":"","ref":"Interval.IntegerInterval.html#equal?/2"},{"type":"function","title":"Interval.IntegerInterval.inclusive_left?/1","doc":"","ref":"Interval.IntegerInterval.html#inclusive_left?/1"},{"type":"function","title":"Interval.IntegerInterval.inclusive_right?/1","doc":"","ref":"Interval.IntegerInterval.html#inclusive_right?/1"},{"type":"function","title":"Interval.IntegerInterval.intersection/2","doc":"","ref":"Interval.IntegerInterval.html#intersection/2"},{"type":"function","title":"Interval.IntegerInterval.left/1","doc":"","ref":"Interval.IntegerInterval.html#left/1"},{"type":"function","title":"Interval.IntegerInterval.new/1","doc":"","ref":"Interval.IntegerInterval.html#new/1"},{"type":"function","title":"Interval.IntegerInterval.new/3","doc":"","ref":"Interval.IntegerInterval.html#new/3"},{"type":"function","title":"Interval.IntegerInterval.overlaps?/2","doc":"","ref":"Interval.IntegerInterval.html#overlaps?/2"},{"type":"function","title":"Interval.IntegerInterval.partition/2","doc":"","ref":"Interval.IntegerInterval.html#partition/2"},{"type":"type","title":"Interval.IntegerInterval.point_type/0","doc":"","ref":"Interval.IntegerInterval.html#t:point_type/0"},{"type":"function","title":"Interval.IntegerInterval.right/1","doc":"","ref":"Interval.IntegerInterval.html#right/1"},{"type":"function","title":"Interval.IntegerInterval.strictly_left_of?/2","doc":"","ref":"Interval.IntegerInterval.html#strictly_left_of?/2"},{"type":"function","title":"Interval.IntegerInterval.strictly_right_of?/2","doc":"","ref":"Interval.IntegerInterval.html#strictly_right_of?/2"},{"type":"type","title":"Interval.IntegerInterval.t/0","doc":"An interval of point type `Integer`","ref":"Interval.IntegerInterval.html#t:t/0"},{"type":"function","title":"Interval.IntegerInterval.unbounded_left?/1","doc":"","ref":"Interval.IntegerInterval.html#unbounded_left?/1"},{"type":"function","title":"Interval.IntegerInterval.unbounded_right?/1","doc":"","ref":"Interval.IntegerInterval.html#unbounded_right?/1"},{"type":"function","title":"Interval.IntegerInterval.union/2","doc":"","ref":"Interval.IntegerInterval.html#union/2"},{"type":"module","title":"Interval.Macro","doc":"Macro helpers for Interval","ref":"Interval.Macro.html"},{"type":"function","title":"Interval.Macro.define_interval/1","doc":"","ref":"Interval.Macro.html#define_interval/1"},{"type":"module","title":"Interval.NaiveDateTimeInterval","doc":"Represents a continuous interval containing `NaiveDateTime`\n\nDefines a struct with two fields, `left` and `right`, representing the left and right endpoints of the interval.\nThe endpoint fields are of type `t:Interval.endpoint(NaiveDateTime)`\n\nThis module delegates most functionality to the `Interval` module.","ref":"Interval.NaiveDateTimeInterval.html"},{"type":"function","title":"Interval.NaiveDateTimeInterval.adjacent?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#adjacent?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.adjacent_left_of?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#adjacent_left_of?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.adjacent_right_of?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#adjacent_right_of?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.contains?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#contains?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.contains_point?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#contains_point?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.difference/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#difference/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.discrete?/0","doc":"","ref":"Interval.NaiveDateTimeInterval.html#discrete?/0"},{"type":"function","title":"Interval.NaiveDateTimeInterval.embed_as/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#embed_as/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.empty?/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#empty?/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.equal?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#equal?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.inclusive_left?/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#inclusive_left?/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.inclusive_right?/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#inclusive_right?/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.intersection/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#intersection/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.left/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#left/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.new/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#new/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.new/3","doc":"","ref":"Interval.NaiveDateTimeInterval.html#new/3"},{"type":"function","title":"Interval.NaiveDateTimeInterval.overlaps?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#overlaps?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.partition/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#partition/2"},{"type":"type","title":"Interval.NaiveDateTimeInterval.point_type/0","doc":"","ref":"Interval.NaiveDateTimeInterval.html#t:point_type/0"},{"type":"function","title":"Interval.NaiveDateTimeInterval.right/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#right/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.strictly_left_of?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#strictly_left_of?/2"},{"type":"function","title":"Interval.NaiveDateTimeInterval.strictly_right_of?/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#strictly_right_of?/2"},{"type":"type","title":"Interval.NaiveDateTimeInterval.t/0","doc":"An interval of point type `NaiveDateTime`","ref":"Interval.NaiveDateTimeInterval.html#t:t/0"},{"type":"function","title":"Interval.NaiveDateTimeInterval.unbounded_left?/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#unbounded_left?/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.unbounded_right?/1","doc":"","ref":"Interval.NaiveDateTimeInterval.html#unbounded_right?/1"},{"type":"function","title":"Interval.NaiveDateTimeInterval.union/2","doc":"","ref":"Interval.NaiveDateTimeInterval.html#union/2"},{"type":"module","title":"Interval.Support.EctoType","doc":"Implements support for auto-implementing Ecto.Type.","ref":"Interval.Support.EctoType.html"},{"type":"module","title":"Example - Interval.Support.EctoType","doc":"use Interval.Support.EctoTypeType, ecto_type: :numrange","ref":"Interval.Support.EctoType.html#module-example"},{"type":"function","title":"Interval.Support.EctoType.from_postgrex_range/2","doc":"Convert a `Postgrex.Range` to a struct of type `module`","ref":"Interval.Support.EctoType.html#from_postgrex_range/2"},{"type":"function","title":"Interval.Support.EctoType.supported?/0","doc":"Returns if Interval was compiled with support for `Ecto.Type`","ref":"Interval.Support.EctoType.html#supported?/0"},{"type":"function","title":"Interval.Support.EctoType.to_postgrex_range/2","doc":"Convert an `Interval` struct to a `Postgrex.Range`.","ref":"Interval.Support.EctoType.html#to_postgrex_range/2"},{"type":"exception","title":"Interval.IntervalOperationError","doc":"","ref":"Interval.IntervalOperationError.html"},{"type":"extras","title":"Readme","doc":"# ![Interval](assets/banner.png \"Interval\")\n\n[![CI](https://github.com/tbug/elixir_interval/actions/workflows/ci.yml/badge.svg)](https://github.com/tbug/elixir_interval/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/interval.svg)](https://hex.pm/packages/interval)\n[![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/interval/)\n\nDatatype and operations for both discrete and continuous intervals,\nInspired by [PostgreSQL's range types](https://www.postgresql.org/docs/current/rangetypes.html).\n\nFind the documentation at https://hexdocs.pm/interval/","ref":"readme.html"},{"type":"extras","title":"Installation - Readme","doc":"The package can be installed by adding `interval` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:interval, \"~> 2.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Ecto & Postgres support - Readme","doc":"The builtin types (Like `Interval.DateTimeInterval`) can be used as an `Ecto.Type`\nwhich will convert to Postgres' range types.\n\n```elixir\n# ...\n  schema \"reservations\" do\n    field :period, Interval.DateTimeInterval\n    # ...\n  end\n# ...\n```","ref":"readme.html#ecto-postgres-support"},{"type":"extras","title":"Built-in Interval Types - Readme","doc":"- `Interval.IntegerInterval` A discrete interval between two integers.\n- `Interval.FloatInterval` A continuous interval between two floats.\n- `Interval.DecimalInterval` A continuous interval between two `Decimal` structs.\n- `Interval.DateInterval` A discrete interval between two `Date` structs.\n- `Interval.DateTimeInterval` A continuous interval between two `DateTime` structs.\n- `Interval.NaiveDateTimeInterval` A continuous interval between two `NaiveDateTime` structs.\n\nSee `Interval` for reference documentation on the available API functions.\n\n\nNote though, that this feature only works with `Postgrex`, as the\nintervals are converted to a `Postgrex.Range` struct which maps to the correct\nrange type in the database (like `tstzrange` etc.)","ref":"readme.html#built-in-interval-types"},{"type":"extras","title":"Defining your own interval type - Readme","doc":"The library contains a `use` macro that does most of the work for you.\n\nYou must implement the `Interval.Behaviour`, which contains a handful of functions.\n\nThis is the full definition of the built-in `Interval.DecimalInterval`:\n\n```elixir\ndefmodule Interval.DecimalInterval do\n  use Interval, type: Decimal, discrete: false\n\n  if Interval.Support.EctoType.supported?() do\n    use Interval.Support.EctoType, ecto_type: :numrange\n  end\n\n  @impl true\n  @spec point_normalize(any()) :: {:ok, Decimal.t()} | :error\n  def point_normalize(a) when is_struct(a, Decimal), do: {:ok, a}\n  def point_normalize(_), do: :error\n\n  @impl true\n  @spec point_compare(Decimal.t(), Decimal.t()) :: :lt | :eq | :gt\n  def point_compare(a, b) when is_struct(a, Decimal) and is_struct(b, Decimal) do\n    Decimal.compare(a, b)\n  end\nend\n```","ref":"readme.html#defining-your-own-interval-type"},{"type":"extras","title":"More Examples - Readme","doc":"","ref":"readme.html#more-examples"},{"type":"extras","title":"Integer intervals - Readme","doc":"Integer intervals are discrete intervals (just like the `int4range` in Postgres).\n\n```elixir\nalias Interval.IntegerInterval\n# ...\na = IntegerInterval.new(1, 4, \"[]\")\n# [1, 5)\nb = IntegerInterval.new(2, 5, \"[]\")\n# [2, 6)\n\nassert IntegerInterval.contains?(a, b)\nassert IntegerInterval.overlaps?(a, b)\n\nc = IntegerInterval.intersection(a, b) # [2, 5)\nd = IntegerInterval.union(a, b) # [1, 6)\ne = IntegerInterval.difference(a, b) # [1, 2)\n```\n\nDiscrete intervals are always normalized to the bound form `[)` (just like in Postgres).","ref":"readme.html#integer-intervals"},{"type":"extras","title":"DateTime intervals - Readme","doc":"DateTime intervals are continuous intervals (just like `tstzrange` in Postgres).\n\n```elixir\nalias Interval.DateTimeInterval\n# ...\n# default bound is  \"[)\"\na = DateTimeInterval.new(~U[2022-01-01 00:00:00Z], ~U[2023-01-01 00:00:00Z])\nb = DateTimeInterval.new(~U[2018-07-01 00:00:00Z], ~U[2022-03-01 00:00:00Z])\n\nDateTimeInterval.intersection(a, b)\n\n# %DateTimeInterval{\n#   left: {:inclusive, ~U[2022-01-01 00:00:00Z]},\n#   right: {:exclusive, ~U[2022-03-01 00:00:00Z]}\n# }\n```","ref":"readme.html#datetime-intervals"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"2.0.0-alpha.2 - Changelog","doc":"","ref":"changelog.html#2-0-0-alpha-2"},{"type":"extras","title":"Added - Changelog","doc":"- `partition/2` now also accepts an interval as it's second argument.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- `adjacent?/2` is now exposed on the interval module via `defdelegate` in the using macro.","ref":"changelog.html#fixed"},{"type":"extras","title":"2.0.0-alpha.1 - 2025-03-10 - Changelog","doc":"","ref":"changelog.html#2-0-0-alpha-1-2025-03-10"},{"type":"extras","title":"Added - Changelog","doc":"- `exclusive_left?/1` and `exclusive_right?/1`\n- `adjacent?/2` (which just checks for adjacency in both directions)\n- `new/1` now accepts option `empty: boolean()`\n- `union/2` will raise `Interval.IntervalOperationError` when the intervals are disjoint.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- `contains?/2` bug - issue #29\n- `contains?/2` bug - empty interval was never contained by anything which doesn't align with Postgres.\n\n\n## [1.0.0] - 2025-03-04","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- All interval implementations now defdelegate all Interval API functions, such that you can\n  call e.g. `union/2` on your own Interval type: `MyInterval.union(a, b)`\n- Introducing a `new/3` helper that takes arguments `new(left, right, bounds \\\\ \"[)\")`.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- All builtins are now suffixed with \"Interval\" which makes aliasing easier, e.g. `alias Interval.DateInterval`\n- Interval modules must now implement `point_normalize/1` instead of `point_valid?/1`, which\n  allows the module to coerce values into canonical values (i.e. -0.0 to +0.0, for OTP 27)","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Removed the Inspect protocol. Inspect now outputs the struct as-is.\n- `size/1` - Currently no good way of doing it generally. You can easily implement this yourself.\n- `new/1` will no longer accept `:unbound` (this came from the Ecto.Type, but not it handles this conversion interally to not polute `Interval`)","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"## [v0.3.4] - 2023-03-01","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Added `Inspect` protocol implementation for all intervals created with `use Interval`\n  (which includes all builtin types) so they now look like `#Interval.Float<[1.0, 3.0)>`\n  instead of `%Interval.Float{left: {:inclusive, 1.0}, right: {:exclusive, 3.0}}`\n- Support for intervals of `NaiveDateTime`.\n- A Logo. For no good reason.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed typespec on `size/1` for `Interval.DateTime`\n- Fixed dialyzer warnings.\n- Incorrect docs for `union/2` (#25)\n\n## [v0.3.3] - 2022-11-22","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- The optional dependencies was also specified as test and dev only, which\n  is not what we want. We want them optional, but all environments.","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"## [v0.3.2] - 2022-11-22","ref":"changelog.html#security"},{"type":"extras","title":"Added - Changelog","doc":"","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Issue #19. Could not compile when the dependant project did not have Ecto included,\n  which was a bug.","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"## [v0.3.1] - 2022-11-21","ref":"changelog.html#security"},{"type":"extras","title":"Added - Changelog","doc":"- Added type and typespecs for builtin types.\n- Added additional documentation in `Interval`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"## [v0.3.0] - 2022-11-21","ref":"changelog.html#security"},{"type":"extras","title":"Added - Changelog","doc":"- Mostly automatic support `Ecto.Type` (including for builtin interval types)\n- `left/1` and `right/1` to extract the left and right values from the interval.\n- Builtin `Jason.Encoder` support.\n- `Interval.__using__` option `jason_encoder` for including encoder. Defaults to `true`.\n- `Interval.to_map/1` to convert an Interval struct to a map suitible for JSON and similar serialization.\n- `Interval.Decimal` for `Decimal` support.","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- `Interval.__using__` option `discrete` is now optional, and defaults to `false`","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"## [v0.2.0] - 2022-10-27","ref":"changelog.html#security"},{"type":"extras","title":"Added - Changelog","doc":"- Allow opting out of built in implementations by configuring `:interval, Interval.Float: false`\n- Adding `Interval.Intervalable` protocol, which allows you to define what interval implementation\n  to use for value types. This is purely for ergonomic reasons.\n- Special-case for empty intervals, which doesn't require implementation-specific behaviour.\n- Adding `Interval.contains_point?/2`\n- Adding `Interval.partition/2`\n- Adding `Interval.size/1`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Various `RuntimeError`s handling bad input to a function has been converted to `ArgumentError`s\n- `Point.previous(a)` and `Point.next(a)` became `point_step/2` in the `Interval.Behaviour`.\n- `Interval.new/1` now requires a `:module` option of the specific implementation to use,\n  however the implementation has a `new/1` that infers this when creating new intervals.","ref":"changelog.html#changed"},{"type":"extras","title":"Removed - Changelog","doc":"- The idea of a \"zero\" point was removed because it doesn't make sense for all intervals.\n- Removed the `Interval.Point` protocol in favor of a behaviour for the entire interval.\n- Removed `Interval.size/2`\n\n## [v0.1.3] - 2022-10-12","ref":"changelog.html#removed"},{"type":"extras","title":"Added - Changelog","doc":"- Added `Interval.size/2`.\n- Added parameterized typespec `t:Interval.t/1`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- The internal `Endpoint` struct has been replaced by a simple 2-tuple.\n- Empty intervals are now represented by two identical exclusive points.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a bug in `Interval.intersection/2` and `Interval.union/2` that causes incorrect bounds\n  in some cases.\n\n## [v0.1.2] - 2022-10-10","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a correctness bug in intersection, where intersections between\n  intervals containing unbounded endpoints would be incorrectly computed.","ref":"changelog.html#fixed"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}